@@ -4,7 +4,7 @@ use link::Link;
 
 // gets latest link created to the specific base
 pub fn get_latest_link(base: EntryHash, tag: Option<LinkTag>) -> UtilsResult<Option<Link>> {
-    let profile_info = get_links(base.into(), tag)?.into_inner();
+    let profile_info = get_links(base.into(), tag)?;
 
     // Find the latest
     let latest_info =
